@@ -3,12 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1304';
+our $VERSION = '0.1305';
 
 use Moo;
 use strictures 2;
 use namespace::clean;
 
+use Carp 'croak';
 use Imager ();
 use List::SomeUtils 'first_index';
 use Music::Chord::Namer 'chordname';
@@ -139,7 +140,7 @@ sub BUILD {
     $self->chord( [ [ $self->position, $self->chord ] ] )
         unless ref $self->chord;
 
-    die 'chord length and string number differ'
+    croak 'chord length and string number differ'
         if $self->chord && length( $self->chord->[0][1] ) != $self->strings;
 
     my @scale = qw/C Db D Eb E F Gb G Ab A Bb B/;
@@ -500,17 +501,17 @@ sub _output_image {
     my ($self, $img) = @_;
     my $name = $self->outfile . '.' . $self->type;
     $img->write( type => $self->type, file => $name )
-        or die "Can't save $name: ", $img->errstr;
+        or croak "Can't save $name: ", $img->errstr;
 }
 
 sub _positive_int {
     my ($arg) = @_;
-    die "$arg is not a positive integer" unless $arg =~ /^[1-9]\d*$/;
+    croak "$arg is not a positive integer" unless $arg =~ /^[1-9]\d*$/;
 }
 
 sub _boolean {
     my ($arg) = @_;
-    die "$arg is not a Boolean value" unless $arg =~ /^[10]$/;
+    croak "$arg is not a Boolean value" unless $arg =~ /^[10]$/;
 }
 
 1;
@@ -527,7 +528,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1304
+version 0.1305
 
 =head1 SYNOPSIS
 
@@ -546,6 +547,7 @@ version 0.1304
     chord    => [[1,'022000'], [2,'--1342'], [7,'-13321']], # Em chords
     frets    => 13,
     absolute => 1,
+    size     => 50, # relative units, not pixels
     outfile  => 'fretboard',
     horiz    => 1,
     verbose  => 1,
@@ -660,7 +662,8 @@ Default: C<5>
 
   $size = $dia->size;
 
-The relative size of the diagram.
+The relative size of the diagram.  The smallest visible diagram is
+B<size> = C<6>.
 
 Default: C<30>
 
@@ -713,8 +716,8 @@ Default: C<0>
 
   $image = $dia->image;
 
-Return the image from the B<draw> method instead of writing it to a
-file.
+Boolean to return the image from the B<draw> method instead of writing
+it to a file.
 
 Default: C<0>
 
@@ -752,8 +755,8 @@ Default: C<black>
 Show a chord name or not.
 
 Sometimes the computed chord name is not accurate or desired.  In
-those cases, either set the B<showname> to a string of your choosing
-before drawing, or to C<0> for no chord name.
+those cases, either set the B<showname> to a string of your choosing,
+or to C<0> for no chord name.
 
 Default: C<1>
 
@@ -802,7 +805,7 @@ Create a new C<Music::FretboardDiagram> object.
 =head2 draw
 
   $dia->draw;
-  $image = $dia->draw;
+  $image = $dia->draw; # if the image attr is set
 
 Render the requested chord diagram as an image file of the given
 B<type>.
